# -*- coding: utf-8 -*-
from __future__ import absolute_import, unicode_literals

from addthis.api import Addthis

from addthis.exceptions import AddthisError, AddthisValidationError

__author__ = 'Alex Parinov'
__email__ = 'creafz@gmail.com'
__license__ = 'MIT'
__version__ = '0.1.2'

__all__ = [
    '__author__',
    '__email__',
    '__license__',
    '__version__',
    'AddthisError',
    'AddthisValidationError',
    'Addthis'
]
